# survInsights

[![PyPI version](https://img.shields.io/pypi/v/survinsights.svg)](https://pypi.org/project/survinsights/)
[![PyPI Python versions](https://img.shields.io/pypi/pyversions/survinsights.svg)](https://pypi.org/project/survinsights/)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://spdx.org/licenses/MIT.html)

_survinsights_ is a framework for interpreting survival models

## Quick description

_survinsights_ is a Python 3 package 

## Notebook tutorial

The Jupyter notebooks in folder "examples" give useful tutorials of how to use the framework
